@@ -16,8 +16,8 @@ PORT = 0
 ini = False
 
 def exec_and_return(expression):
-    exec(f"""locals()['temp'] = {expression}""")
-    return locals()['temp']
+    exec(f"""globals()['temp'] = {expression}""")
+    return globals()['temp']
 
 
 def init(_host,_port):
